/*
	EAN13 - An EAN13 Barcode Widget.
	Copyright © 2010-2011,2015 Harry Whitfield

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License as
	published by the Free Software Foundation; either version 2 of
	the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public
	License along with this program; if not, write to the Free
	Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
	MA	02110-1301	USA
	
	EAN13 - version 1.0.2
	3 January, 2011 - revised 7 May, 2015
	Copyright © 2010-2011,2015 Harry Whitfield
	mailto:g6auc@arrl.net

	This program is a modification and translation into JavaScript of the Ean13 function
	in the openbarcodes.cpp file in the openbarcodes package by Grandzebu.

	To use it, you need to install the ean13.ttf font into your system. The ean13.ttf
	font was copied from the openbarcodes package which was downloaded from
	http://sourceforge.net/projects/openbarcodes/

	Here is an extract from the license contained in the openbarcodes package:

	Copyright (C) 2006 (Grandzebu)
	These programs and the fonts which are supplied with it are free, you can redistribute
	it and/or modify it under the terms of the GNU General Public License as published by
	the Free Software Foundation either version 2 of the License, or (at your option) any
	later version. The barcode encoding functions, source code and library, are governed
	by the GNU Lesser General Public License (GNU LGPL).

	These programs are distributed in the hope that they will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You may download a copy of the license from: http://www.gnu.org/licenses/gpl.html
*/

/*properties
    charAt, charCodeAt, code, fromCharCode, length, map, match, text
*/

var EAN13 = (function () {
	"use strict";

    var enc = [
    	["0001101", "0100111", "1110010"],
        ["0011001", "0110011", "1100110"],
        ["0010011", "0011011", "1101100"],
        ["0111101", "0100001", "1000010"],
        ["0100011", "0011101", "1011100"],
        ["0110001", "0111001", "1001110"],
        ["0101111", "0000101", "1010000"],
        ["0111011", "0010001", "1000100"],
        ["0110111", "0001001", "1001000"],
        ["0001011", "0010111", "1110100"]
    ],

		first = [
			"AAAAAA", "AABABB", "AABBAB", "AABBBA", "ABAABB",
			"ABBAAB", "ABBBAA", "ABABAB", "ABABBA", "ABBABA"
		],

		aBase = "A".charCodeAt(0), bBase = "K".charCodeAt(0), cBase = "a".charCodeAt(0),

		itself = function (input) {		// input 12 digits + optional checkdigit
			var first0, i, checksum, useA, output, barmap;
	
			function val(i) {
				return Number(input.charAt(i));
			}
	
			// Check for exactly 12 or 13 digits
			if (input.match(/^\d{12,13}$/) === null) {
				return null;	// bad input format
			}
	
			//Calculate the checksum
			checksum = 0;
			for (i = 11; i > 0; i -= 2) {
				checksum += val(i);
			}
			checksum *= 3;
			for (i = 10; i >= 0; i -= 2) {
				checksum += val(i);
			}
			checksum = (10 - (checksum % 10)) % 10;
			if (input.length === 13) {
				if (checksum !== val(12)) {
					return null;		// bad checksum
				}
			} else {
				input += checksum;
			}
	
			// The first digit is passed through
			output = input.charAt(0);
			barmap = "101";		// start sentinel
	
			first0 = first[val(0)];	// encoding of next six digits depends on first digit
			for (i = 1; i < 7; i += 1) {
				useA = first0.charAt(i - 1) === "A";
				output += String.fromCharCode(val(i) + (useA ? aBase : bBase));
				barmap += enc[val(i)][useA ? 0 : 1];
			}
			output += "*";		// middle sentinel
			barmap += "01010";
	
			for (i = 7; i < 12; i += 1) {
				output += String.fromCharCode(val(i) + cBase);
				barmap += enc[val(i)][2];
			}
			output += String.fromCharCode(checksum + cBase);
			barmap += enc[checksum][2];
	
			output += "+";		// end sentinel
			barmap += "101";
	
			// text should be displayed using the Code EAN13 font.
			return {text: output, map: barmap, code: input};	
		};
	
	return itself;
}());
/*
var data = "5012818160864";
var result = EAN13(data);
print(result.text);
print(result.map);
print(result.code);
*/