/*
	EAN13 - An EAN13 Barcode Widget.
	Copyright © 2008-2011,2015 Harry Whitfield

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License as
	published by the Free Software Foundation; either version 2 of
	the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public
	License along with this program; if not, write to the Free
	Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
	MA	02110-1301	USA
	
	EAN13 - browser version 1.0
	8 May, 2015
	Copyright © 2008-2011,2015 Harry Whitfield
	mailto:g6auc@arrl.net
*/

/*global newImage, newText, newInput, newTextArea, updatePrefs, newSelector, addToMenu */

/*properties
    body, checked, close, div, length, onclick, onmouseout, onmouseover, opacity,
    removeChild, selectedIndex, setAttribute, src, style, title, value
*/

////////////////////////////// Start of the Barcode Widget ///////////////////////////////

// newImage(hOffset, vOffset, width, height, src, zOrder, opacity)
// newText(hOffset, vOffset, width, height, value, zOrder, style)
// newTextArea(hOffset, vOffset, cols, rows, value, zOrder, style)
// newInput(hOffset, vOffset, width, height, value, zOrder, style)
// newCanvas(hOffset, vOffset, width, height, src, zOrder, opacity, hRegP, vRegP)
// newSelector(hOffset, vOffset, width, height, src, zOrder, opacity)

var bg = newImage(0, 0, 496, 235, "Resources/Images/bg.png", 1, 1.0);

var base = "Resources/buttons/";

var helpButton  = newImage(465,  210, 30,  22, base + "help.png",    2);	// customized

var redButton   = newImage(8,      6, 21,  14, base + "red.png",     2);
var amberButton = newImage(29,     6, 21,  14, base + "amber.png",   2);
var greenButton = newImage(50,     6, 14,  14, base + "green.png",   2);

redButton.title = "Close the widget.";
amberButton.title = "Clear the data fields.";
greenButton.title = "Save the barcode as EPS data.";

helpButton.title  = "Displays information about this program.";

var style = "font-family:'Lucida Grande','Lucida Sans Unicode';background-color:transparent;text-align:center;border:none;color:black;font-size:12px;";
var title = newText(190, 2, 90, 20, "EAN13 Barcode", 2, style);				// customized

var star = newImage(472, 4, 18, 18, "Resources/Images/star.png", 2, 1.0);
star.title = "Hide or show the settings controls.";

style = "font-family:Arial;font-size:14px;border:none;background-color:#CCFFCC";	// set fScale to 6.0
var input = newInput(25, 30, 87, 20, "", 2, style);
input.title = "Enter 12 or 13 digits.";

var go = newImage(64, 58, 32, 32, "Resources/Images/return.png", 2, 1.0);

style = "font-family:Arial;font-size:14px;border:none;";	// set fScale to 6.0
var output = newInput(25, 95, 87, 20, "", 2, style);

style = "font-family:'Lucida Grande','Lucida Sans Unicode';background-color:transparent;text-align:center;border:none;color:black;font-size:14px;";
var label = newInput(22, 128, 100, 20, "Code EAN13 Text", 2, style);

style = "font-family:'Code EAN13';font-size:48px;border:none;text-align:center;";	// set fScale to 6.0
var ean13Text = newTextArea(16, 150, 13, 1, "", 3, style);

var drawBorderBox = newInput(450,  4, 20, 16, "Draw Border",  2);	// was 115
drawBorderBox.setAttribute("type", "checkbox");
var drawBorderButton = newInput(363, 4, 20, 16, "Draw Border", 2);
drawBorderButton.setAttribute("type", "button");
drawBorderButton.onclick = function () {
	drawBorderBox.checked = !drawBorderBox.checked;
	updatePrefs();
};
drawBorderBox.title = "Check this box to have a border drawn around the barcode image.";

var useEAN13FontBox = newInput(175,  4, 20, 16, "Use EAN13 Font",   2);
useEAN13FontBox.setAttribute("type", "checkbox");
var useEAN13FontButton = newInput(68, 4, 20, 16, "Use EAN13 Font", 2);	// 135
useEAN13FontButton.setAttribute("type", "button");
useEAN13FontButton.onclick = function () {
	useEAN13FontBox.checked = !useEAN13FontBox.checked;
	updatePrefs();
};
useEAN13FontBox.title = "Check this box to use the EAN13 font in the Code EAN13 Text field.";
	
style = "font-family:Arial;font-size:14px";	// set fScale to 6.0

var epsData = newTextArea(0, 250, 78, 10, "", 3, style);
epsData.title = "For EPS data.";
epsData.style.opacity = 0.0;

var barChart = null;	// newCanvas(frm, 0, 0, width, height, zOrder + 1);

//////////////////////////////////// Menus Customized ////////////////////////////////////

var MenuArray = [
	['100', '125', '150', '175', '200', '225', '250']
];

var MenuTitleArray = [
	"Choose the size of the EAN13 barcode image (in percent)."
];

var MenuSelectedIndex = [0];

var Menu = [];

Menu[0] = newSelector(305, 4, 110, 20, "", 2);

var i;

for (i = 0; i < MenuArray.length; i += 1) {
	addToMenu(Menu[i],  MenuArray[i]);
	Menu[i].selectedIndex = MenuSelectedIndex[i];
	Menu[i].title = MenuTitleArray[i];
}

//////////////////////////////////////////////////////////////////////////////////////////

function normalButtons() {
	var base = "Resources/buttons/";
	
	redButton.src   = base + "red.png";
	amberButton.src = base + "amber.png";
	greenButton.src = base + "green.png";
}

function activeButtons() {
	var base = "Resources/buttons/";
	
	redButton.src   = base + "redCross.png";
	amberButton.src = base + "amberMinus.png";
	greenButton.src = base + "greenPlus.png";
}

redButton.onmouseover = function () {
	activeButtons();
};

redButton.onmouseout = function () {
	normalButtons();
};

amberButton.onmouseover = function () {
	activeButtons();
};

amberButton.onmouseout = function () {
	normalButtons();
};

greenButton.onmouseover = function () {
	activeButtons();
};

greenButton.onmouseout = function () {
	normalButtons();
};

redButton.onclick = function () {
	window.close();
};

function removeBarChart() {
	if (barChart !== null) {
		document.body.removeChild(barChart.div);
		barChart = null;
	}
}

function clearData() {
	input.value =
		output.value =
		ean13Text.value = "";
	removeBarChart();
	epsData.style.opacity = 0.0;
}

amberButton.onclick = function () {
	clearData();
};

/*
greenButton.onclick = function () {
	alert("Sorry - not yet implemented.");
};
*/

//////////////////////////////////////////////////////////////////////////////////////////

helpButton.onmousedown = function () { this.style.opacity = "0.5"; };
helpButton.onmouseup   = function () { this.style.opacity = "1.0"; window.open("Help.html"); };

//////////////////////////////////////////////////////////////////////////////////////////
