/*
	EAN13 - An EAN13 Barcode Widget.
	Copyright © 2008-2011,2015 Harry Whitfield

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License as
	published by the Free Software Foundation; either version 2 of
	the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public
	License along with this program; if not, write to the Free
	Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
	MA	02110-1301	USA
	
	EAN13 - browser version 1.0
	8 May, 2015
	Copyright © 2008-2011,2015 Harry Whitfield
	mailto:g6auc@arrl.net
*/

///////////////////////////////// Start  of  the Canvas functions ////////////////////////

function clear(canvas) {
	canvas.ctx.clearRect(0, 0, canvas.width, canvas.height);
}

function makeBackground(canvas, width, height, bgColor, borderColor) {
	canvas.ctx.beginPath();
	canvas.ctx.rect(0, 0, width, height);
	canvas.ctx.fillStyle = borderColor;
	canvas.ctx.fill();
	canvas.ctx.beginPath();
	canvas.ctx.rect(1, 1, width - 2, height - 2);
	canvas.ctx.fillStyle = bgColor;
	canvas.ctx.fill();
}

function plotBar(canvas, x, y, width, height, color) {
	canvas.ctx.beginPath();
	canvas.ctx.rect(x, y, width, height);
	canvas.ctx.fillStyle = color;
	canvas.ctx.fill();
}

function drawTheText(canvas, text, hOff, vOff, font) {
	canvas.ctx.save();
	canvas.ctx.font = font;
	canvas.ctx.fillText(text, hOff, vOff); 
	canvas.ctx.restore();
}

///////////////////////////////// End  of  the Canvas functions //////////////////////////

function drawEAN13(barChart, scale, map, code, borderPref) {
	var width	= barChart.width,
	    height	= barChart.height,
	    graphBgColor = "#FFFFFF",
	    graphFgColor = "#000000",
	    barHeight1 = Math.ceil(40 * scale),
	    barHeight2 = Math.ceil(48 * scale),
	    textBase   = Math.ceil(64 * scale),
	    barYBase   = Math.ceil(12 * scale),
	    i,
	    h,
	    font = String(Math.floor(12 * scale)) + 'px Courier';
		
	if (borderPref) {
		makeBackground(barChart, width, height, graphBgColor, graphFgColor);
	} else {
		makeBackground(barChart, width, height, graphBgColor, graphBgColor);
	}

	for (i = 0; i < map.length; i += 1) {
		if (map[i] === "1") {
			h = (i < 3) || (i === 46) || (i === 48) || (i > 91) ? barHeight2 : barHeight1;
			plotBar(barChart, (i + 10) * scale, barYBase, scale, h, graphFgColor);
		}
	}
	
	drawTheText(barChart, code[0], Math.ceil(1.5 * scale), textBase, font);
	
	for (i = 1; i < 7; i += 1) {
		drawTheText(barChart, code[i], Math.ceil((7 * i +  6) * scale), textBase, font);
	}
	
	for (i = 7; i < 13; i += 1) {
		drawTheText(barChart, code[i], Math.ceil((7 * i +  10) * scale), textBase, font);
	}
}
