/*
	EAN13 - An EAN13 Barcode Widget.
	Copyright © 2008-2011,2015 Harry Whitfield

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License as
	published by the Free Software Foundation; either version 2 of
	the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public
	License along with this program; if not, write to the Free
	Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
	MA	02110-1301	USA
	
	EAN13 - browser version 1.0
	8 May, 2015
	Copyright © 2008-2011,2015 Harry Whitfield
	mailto:g6auc@arrl.net
*/

/*properties
    borderPref, charAt, value
*/

function makeEPS(map, code, border) {
	var low = 8, low1 = 13, high = 68, textY = 4;

	function bar(x0, y0, x1, y1) {
		return "n " +
			   	x0 + " " + y0 + " m " + x0 + " " + y1 + " l " + 
			   	x1 + " " + y1 + " l " + x1 + " " + y0 + " l " +
			  	"c f\r\n";
	}

	function header0() {
		var ps = "";
		ps += "%!PS-Adobe-3.0 EPSF-3.0\r\n";
		ps += "%%BoundingBox: 0 0 108 72\r\n";
		ps += "%%Title: (EAN13 Barcode " + code + ")\r\n";
		ps += "%%Creator: (EAN13 Barcode Widget by G6AUC)\r\n";
		ps += "%%CreationDate: (" + new Date() + ")\r\n";
		ps += "%%DocumentFonts: Helvetica\r\n";
		ps += "%%DocumentNeededFonts: Helvetica\r\n";
		ps += "%%DocumentSuppliedFonts:\r\n";
		ps += "%%EndComments\r\n";
		return ps;
	}
	
	function header1() {
		var ps = "";
		ps += "/EAN13_Barcode 20 dict def\r\n";
		ps += "EAN13_Barcode begin\r\n";

		ps += "/ldef {load def} bind def\r\n";
		ps += "/l { transform round exch round exch itransform lineto } bind def\r\n";
//		ps += "/l /lineto ldef\r\n";
		ps += "/m { transform round exch round exch itransform moveto } bind def\r\n";
//		ps += "/m /moveto ldef\r\n";
		ps += "/w /setlinewidth ldef\r\n";
		ps += "/n /newpath ldef\r\n";
		ps += "/c /closepath ldef\r\n";
		ps += "/s /stroke ldef\r\n";
		ps += "/f /fill ldef\r\n";
		ps += "/sh /show ldef\r\n";

		ps += "/lw 0.5 def\r\n";
		ps += "/box { n 0.25 0.25 m 0.25 71.75 l 107.75 71.75 l 107.75 0.25 l c s } def\r\n";
		ps += "/barcode {\r\n";
		ps += "gsave\r\n";
		return ps;
	}

	function leftSentinel() {
		return bar(0, low, 1, high) + bar(2, low, 3, high);
	}
	
	function leftSix() {
		var ps = "", i;
		for (i = 3; i < 45; i += 1) {
			if (map.charAt(i) === "1") {
				ps += bar(i, low1, i + 1, high);
			}
		}
		return ps;
	}
	
	function midSentinel() {
		return bar(46, low, 47, high) + bar(48, low, 49, high);
	}
	
	function rightSix() {
		var ps = "", i;
		for (i = 50; i < 92; i += 1) {
			if (map.charAt(i) === "1") {
				ps += bar(i, low1, i + 1, high);
			}
		}
		return ps;
	}
	
	function rightSentinel() {
		return bar(92, low, 93, high) + bar(94, low, 95, high);
	}
	
	function trailer1() {
		var ps = "";
		ps += "grestore\r\n";
		ps += "} def\r\n";
		return ps;
	}
	
	function showDigit(d, x, y) {
		return "(" + d + ") " + x + " " + y + " m sh\r\n";
	}

	function codeBanner() {
		var ps = "", i;
		ps += "/banner {\r\n";
		ps += "gsave\r\n";
		ps += "/Helvetica findfont 10 scalefont setfont\r\n";
		ps += showDigit(code.charAt(0), 1.5, textY);
		for (i = 1; i < 7; i += 1) {
			ps += showDigit(code.charAt(i), 7 * i + 4, textY);
		}
		for (i = 7; i < 13; i += 1) {
			ps += showDigit(code.charAt(i), 7 * i + 8, textY);
		}
		ps += "grestore\r\n";
		ps += "} def\r\n";
		return ps;
	}

	function trailer2() {
		var ps = "";
		ps += "end\r\n";
		ps += "EAN13_Barcode begin lw w 1.0 1.0 scale\r\n";
		if (border) {
			ps += "box\r\n";
		}
		ps += "gsave 7 0 translate barcode grestore\r\n";
		ps += "banner\r\n";
		ps += "end\r\n";
		ps += "showpage\r\n";
		ps += "%%EOF\r\n";
		return ps;
	}
	
	return header0() + header1() + leftSentinel() + leftSix() + midSentinel() +
		   rightSix() + rightSentinel()  + trailer1() + codeBanner() + trailer2();

}
/*
var code = "5012818160864";
var map = "10100011010110011001101101101110011001000100101010110011010100001110010100100010100001011100101";
print(makeEPS(map, code, true));
*/
