/*
	EAN13 - An EAN13 Barcode Widget.
	Copyright © 2008-2011,2015 Harry Whitfield

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License as
	published by the Free Software Foundation; either version 2 of
	the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public
	License along with this program; if not, write to the Free
	Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
	MA	02110-1301	USA
	
	EAN13 - browser version 1.0
	8 May, 2015
	Copyright © 2008-2011,2015 Harry Whitfield
	mailto:g6auc@arrl.net
*/

/*global Menu, ean13Text, useEAN13FontBox, drawBorderBox, EAN13, input, output,
	removeBarChart, barChart:true, newCanvas, drawEAN13, go, star, drawBorderButton,
	useEAN13FontButton, greenButton, epsData, makeEPS
*/

/*properties
    ceil, checked, code, cols, height, keyCode, map, onchange, onclick,
    onkeypress, onmouseup, opacity, setStyle, style, text, value, which
*/

var sizeMenu = Menu[0];

var scalePref = 1.0;
var borderPref = false;
var useEAN13FontPref = false;

var gMap, gCode;

var updatePrefs = function () {
	"use strict";

	function setFont(useFont) {
		if (useFont) {
			ean13Text.height = 64;
			ean13Text.cols   = 13;
			ean13Text.style.setStyle("font-family: 'code ean13'; font-size: 49px");
		} else {
			ean13Text.height = 20;
			ean13Text.cols   = 20;
			ean13Text.style.setStyle("font-family: arial; font-size: 14px");
		}
	}
	
	useEAN13FontPref = useEAN13FontBox.checked;
	borderPref = drawBorderBox.checked;
	setFont(useEAN13FontPref);
};

// code to process the input data
var doIt = function () {
	"use strict";
	var scale   = scalePref,
		hOffset = 195,
		vOffset =  30,
		width	= Math.ceil(115 * scale),
		height	= Math.ceil(70 * scale),
		zOrder	=  10,
		obj = EAN13(input.value);

	if (obj) {
		gCode = output.value = obj.code;
		gMap  = obj.map;
		ean13Text.value = obj.text;
		removeBarChart();
		barChart = newCanvas(hOffset, vOffset, width, height, "", zOrder, 1.0);
		drawEAN13(barChart, scale, obj.map, obj.code, borderPref);
	}
};

go.onmouseup = function () {
	"use strict";
	doIt();
};

star.onmouseup = function () {
	"use strict";
	drawBorderBox.style.opacity =
		drawBorderButton.style.opacity =
		useEAN13FontBox.style.opacity =
		useEAN13FontButton.style.opacity =
		Menu[0].style.opacity = 1.0 - Menu[0].style.opacity;
};

input.onkeypress = function (event) {
	"use strict";
	var x = event.which || event.keyCode;

	if (x === 13) { 
		doIt();
    } else {
		output.value = "";
		ean13Text.value = "";
		removeBarChart();
    }
};

greenButton.onclick = function () {
	if (barChart !== null) {
		epsData.value = makeEPS(gMap, gCode, borderPref);
		epsData.style.opacity = 1.0;
	}
};

sizeMenu.onchange  = function () {
	scalePref = Number(this.value) / 100;
};

drawBorderBox.onchange  = function () {
	updatePrefs();
};

useEAN13FontBox.onchange  = function () {
	updatePrefs();
};

updatePrefs();
